@@ -1,7 +1,7 @@
 package LWP::UserAgent::Patch::Delay;
 
 our $DATE = '2019-04-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,7 +20,12 @@ my $p_send_request = sub {
     my $ctx  = shift;
     my $orig = $ctx->{orig};
 
-    sleep $config{-between_request} // 1 if $seen++;
+    if ($seen++) {
+        my $secs = $config{-between_request} // 1;
+        log_trace "Sleeping %.1f second(s) between LWP::UserAgent request ...",
+            $secs;
+        sleep $secs;
+    }
     $ctx->{orig}->(@_);
 };
 
@@ -59,7 +64,7 @@ LWP::UserAgent::Patch::Delay - Add sleep() between requests to slow down
 
 =head1 VERSION
 
-This document describes version 0.002 of LWP::UserAgent::Patch::Delay (from Perl distribution LWP-UserAgent-Patch-Delay), released on 2019-04-07.
+This document describes version 0.003 of LWP::UserAgent::Patch::Delay (from Perl distribution LWP-UserAgent-Patch-Delay), released on 2019-04-07.
 
 =head1 SYNOPSIS
 
